/*
    (C) 1995-97 AROS - The Amiga Research OS
    $Id: printfault.c,v 1.1.1.1 2005/03/15 15:54:40 laire Exp $

    Desc:
    Lang: english
*/
#include <proto/exec.h>
#include "dos_intern.h"

#include <aros/debug.h>

/*****************************************************************************

    NAME */
#include <proto/dos.h>

	AROS_LH2(LONG, PrintFault,

/*  SYNOPSIS */
	AROS_LHA(LONG,   code,   D1),
	AROS_LHA(STRPTR, header, D2),

/*  LOCATION */
	struct DosLibrary *, DOSBase, 79, Dos)

/*  FUNCTION
	Prints the header and the text associated with the error code to
	the console (buffered), then sets the value returned by IoErr() to
	the error code given.

    INPUTS
	code   - Error code.
	header - Text to print before the error message. This may be NULL
                 in which case only the error message is printed.

    RESULT
	!=0 if all went well. 0 on failure.

    NOTES

    EXAMPLE

    BUGS

    SEE ALSO
	Fault()

    INTERNALS

    HISTORY
	29-10-95    digulla automatically created from
			    dos_lib.fd and clib/dos_protos.h

*****************************************************************************/
{
    AROS_LIBFUNC_INIT
    AROS_LIBBASE_EXT_DECL(struct DosLibrary *,DOSBase)

    struct Process *me = (struct Process *)FindTask(NULL);
    BPTR            stream;
    LONG            ret = DOSTRUE;
    CONST_STRPTR    str;

    DEBUG_ERRORS(dprintf("PrintFault: code = %ld, header = \"%s\"\n",
			 code, header ? header : (STRPTR) "<NULL>"));

    FAILFORTASK(me, return DOSFALSE;)

    if (code)
    {

#ifdef __MORPHOS__

	stream = me->pr_COS;

#else /* __MORPHOS__ */

	stream = me->pr_CES ? me->pr_CES : me->pr_COS;

#endif /* __MORPHOS__ */

	ASSERT_VALID_PTR(stream);
	ASSERT_VALID_PTR_OR_NULL(header);

	if (header)
	{
	    FPuts(stream, header);
	    FPuts(stream, ": ");
	}
	
	str = DosGetString(code);
	if (str)
	{
	    FPuts(stream, str);
	}
	else
	{                                   /* "Error " */
	    FPrintf(stream, "%s%ld", (LONG) DosGetString(-117), code);
	    ret = DOSFALSE;
	}
	FPutC(stream, '\n');

	/* All done. */
	SetIoErr(code);
    }

    return ret;

    AROS_LIBFUNC_EXIT
} /* PrintFault */
